# -*- coding: utf-8 -*-

import re

from django.forms import fields, Field, Widget, ValidationError
from django.template.loader import render_to_string


class HexColorWidget(Widget):
    def render(self, name, value, attrs=None):
        return render_to_string("form_widgets/color_picker.html", locals())


class HexColorField(Field):
    default_error_messages = {
        "incorrect_value": "Valeur incorrecte. Entrez un # suivi de 3 valeurs hexadécimales. Exemple: #000000"
    }

    widget = HexColorWidget

    def clean(self, value):
        "Valide la valeur hexadécimale indiquée dans le champ."
        super(HexColorField, self).clean(value)
        if value in fields.EMPTY_VALUES:
            return ""
        value = value
        if len(value) != 7 or not re.match("^#[A-F0-9]{6}$", value):
            raise ValidationError(self.error_messages["incorrect_value"])

        return value
